import { Box, useMediaQuery, useTheme } from "@mui/material"
import { NavCard } from "../components/NavCard"
import { createTariffElements } from "../tariffsUtils/createTariffElements"
import SmallIconPena from "@/assets/icons/SmallIconPena"

interface Props {
    content: {
        title: string,
        onClick: () => void
    }[]
    selectedItem: TypePages
}

export const Other = ({
    content,
    selectedItem,

    tariffs,
    user,
    discounts,
    openModalHC,
    userPrivilegies,
    startRequestCreate
}: any) => {
    const theme = useTheme()
    const isTablet = useMediaQuery(theme.breakpoints.down(1000));
const sendRequest = userPrivilegies?.quizManual?.amount > 0 ? startRequestCreate : undefined

    switch (selectedItem) {
        case "hide":
            const filteredBadgeTariffs = tariffs.filter((tariff) => {
                return (
                    tariff.privileges[0].serviceKey === "squiz" &&
                    !tariff.isDeleted &&
                    !tariff.isCustom &&
                    tariff.privileges[0].privilegeId === "squizHideBadge" &&
                    tariff.privileges[0]?.type === "day"
                );
            });
            return <Box
                sx={{
                    justifyContent: "left",
                    display: "grid",
                    gap: "40px",
                    gridTemplateColumns: `repeat(auto-fit, minmax(300px, ${isTablet ? "436px" : "360px"
                        }))`,
                }}
            >
                {createTariffElements(
                    filteredBadgeTariffs,
                    false,
                    user,
                    discounts,
                    openModalHC,
                )}
            </Box>
        case "create":
            const filteredCreateTariffs = tariffs.filter((tariff) => {
                return (
                    tariff.privileges[0].serviceKey === "squiz" &&
                    !tariff.isDeleted &&
                    !tariff.isCustom &&
                    tariff.privileges[0].privilegeId === "quizManual" &&
                    tariff.privileges[0]?.type === "count"
                );
            });
            return <Box
                sx={{
                    justifyContent: "left",
                    display: "grid",
                    gap: "40px",
                    gridTemplateColumns: `repeat(auto-fit, minmax(300px, ${isTablet ? "436px" : "360px"
                        }))`,
                }}
            >
                {createTariffElements(
                    filteredCreateTariffs,
                    false,
                    user,
                    discounts,
                    openModalHC,
                    sendRequest,
                    true,
                    <SmallIconPena/>
                )}
            </Box>
        default:
            return <Box
                sx={{
                    display: "flex",
                    flexWrap: "wrap",
                    width: "100%"
                }}>
                {content.map(data => <NavCard {...data} key={data.title} />)}
            </Box>
    }
}
